@@ -22,7 +22,7 @@ class Route:
         elif method == "GET":
             if endpoint == "https://latency.discord.media/rtc":
                 response = self.session.get(endpoint, json=data)
-            else:
+            if endpoint != "https://latency.discord.media/rtc":
                 response = self.session.get("https://discord.com/api" + endpoint, json=data)
         elif method == "PATCH":
             response = self.session.patch("https://discord.com/api" + endpoint, json=data)
